==> netscape-7.1-i686-1.tgz: usr/lib/netscape/defaults/pref/aim.js <==
/* 0 is for BUCP(AIM), 1 is for TIH, 2 is for ICQ, 3 is for autosignon */
pref("aim.session.sessiontype", 0);

pref("aim.session.firsttry", false);
pref("aim.session.firsthost", "americaonline.aol.com");
pref("aim.session.firstport", 5200);

/* Set to ICQ to be default to ICQ */
pref("aim.session.userconnectionname", "AIM");

/* Proxy prefs for session */
pref("aim.proxy.use", false);
pref("aim.proxy.host", "");
pref("aim.proxy.port", 1080);
pref("aim.proxy.username", "");
pref("aim.proxy.password", "");
pref("aim.proxy.protocol", 1);
 

/* session pref defaults */
pref("aim.session.screenname","");
pref("aim.session.password","");
pref("aim.session.storepassword",false);
pref("aim.session.autologin",true);

/* last successfully signed on screenname of type */
pref("aim.session.latesticqscreenname","");
pref("aim.session.latestaimscreenname","");



/* gen global*/
pref("aim.session.firsttime",true);
pref("aim.session.appfirstlogin",true);
pref("aim.session.finishedwizard", false);

/* perSN*/
pref("aim.session.firstsignon",true);
pref("aim.session.autoreconnect", false);
pref("aim.session.reconnectdialog", false);
pref("aim.session.keepalive", false);



/* Mail integration per SN*/
pref("aim.mail.presence", true);
pref("aim.general.im.smilies", true);
pref("aim.general.im.enterCR", false);
pref("aim.general.im.tabKey", false);
pref("aim.general.im.timeStamp", false);

pref("aim.general.im.showtooltip", "false");
pref("aim.general.contactlist.displaymode", "false");
pref("aim.general.im.statusMode", "false");
pref("aim.general.contactlist.displaymode", "false");


/* no use, consider as gen global*/
pref("aim.im.flashonreceiveim", true);
pref("aim.im.showaccept",false);

/* gen global */
pref("aim.internal.buddy.MaxBuddies",100);


/* gen global */
pref("aim.buddy.TransitionTime",10);


pref("aim.buddy.SndPlaySignOn",true);
pref("aim.buddy.SndPlaySignOff",true);
pref("aim.buddy.SndPlaySignOn_ICQ",true);
/* XXXIMPL Put real sound path in here for the defaults */
pref("aim.buddy.SndSignOn","chrome://aim/skin/sounds/BuddySignon");
pref("aim.buddy.SndSignOn_ICQ","chrome://aim/skin/sounds/BuddySignon_ICQ");
/* XXXIMPL Put real sound path in here for the defaults */
pref("aim.buddy.SndSignOff","chrome://aim/skin/sounds/BuddySignoff");
pref("aim.buddy.SndBuddyOverride",false);
pref("aim.buddy.SndBuddyOverride_ICQ",false);
/* IM pref defaults */
pref("aim.im.playall", true);
pref("icq.im.playall", true);
pref("aim.buddy.SndPlayFirstIncoming",true);
pref("aim.buddy.SndPlayIncoming",true);
pref("aim.buddy.SndPlayOutgoing",true);
pref("aim.buddy.SndPlayFirstIncoming_ICQ",true);
pref("aim.buddy.SndPlayIncoming_ICQ",true);
pref("aim.buddy.SndPlayOutgoing_ICQ",true);
/* XXXIMPL Put real sound path in here for the defaults */
pref("aim.buddy.SndFirstIncoming","chrome://aim/skin/sounds/FirstIncomingIM");
pref("aim.buddy.SndIncoming","chrome://aim/skin/sounds/IncomingIM");
pref("aim.buddy.SndOutgoing","chrome://aim/skin/sounds/OutgoingIM");
pref("aim.buddy.SndFirstIncoming_ICQ","chrome://aim/skin/sounds/FirstIncoming_ICQ");
pref("aim.buddy.SndIncoming_ICQ","chrome://aim/skin/sounds/Incoming_ICQ");
pref("aim.buddy.SndOutgoing_ICQ","chrome://aim/skin/sounds/Outgoing_ICQ");




/* Privacy Pref Defaults */
/* no use, consider as gen global*/
pref("aim.privacy.view",3);
pref("aim.privacy.ChatBlockInvitations",false);
pref("aim.away.hidewindow", false);
pref("aim.away.idlereply", false);
pref("aim.away.disablereply", true);


/* perSN*/
pref("aim.privacy.knockknock",true);


/* perSN, (just for ICQ)*/
pref("aim.privacy.authorization",true);
pref("aim.privacy.onlinestatus",true);

/* perSN*/
pref("aim.away.autoreply", true);
pref("icq.away.autoreply", false);

/* no use, consider as gen global*/
pref("aim.throbber.url","chrome://aim-region/locale/region.properties");


/*AIM new added, perSN*/
pref("aim.general.today.aim", true);
pref("aim.general.today.icq", false);




/* Chat Pref Defaults pre SN, just AIM */
pref("aim.chat.SndPlayIncoming",true);
pref("aim.chat.SndPlayOutgoing",true);
/* IMPL Put real sound path in here for the defaults */
pref("aim.chat.SndIncoming","chrome://aim/skin/sounds/IncomingChat");
/* IMPL Put real sound path in here for the defaults */
pref("aim.chat.SndOutgoing","chrome://aim/skin/sounds/OutgoingChat");
pref("aim.chat.unavailable", false);
pref("aim.chat.FlashChatWin", true);
pref("aim.chat.AnnounceChatRoom", true);


/*Buddy Icons */
pref("aim.buddyicon.acceptfromBuddyList", true);
pref("aim.buddyicon.showknockknock", true);
pref("aim.buddyicon.neveraccept", false);

/*Buddy Icons */
pref("aim.buddyicon.displayBuddyIcons", 0); //0 - buddy list, 1 - never accept, 2 - never display BI.






/*new*/
/* per SN*/
pref("aim.session.connectionname", "AIM");

/* gen global*/


pref("aim.internal.extsessiontype",   0);
pref("aim.internal.extname",          "AIM");
pref("aim.internal.exthost",          "login.oscar.aol.com");
pref("aim.internal.extport",          5190);
pref("aim.internal.extproxyhost",     "");
pref("aim.internal.extproxyport",     1080);
pref("aim.internal.extproxyuser",     "");
pref("aim.internal.extproxypassword", "");
pref("aim.internal.extproxyprotocol", 0);
pref("aim.internal.extisproxy",       false);
pref("aim.internal.extconnectiontype", 0);


pref("aim.internal.intsessiontype",   0);
pref("aim.internal.intname",          "AIM");
pref("aim.internal.inthost",          "login.oscar.aol.com");
pref("aim.internal.intport",          5190);
pref("aim.internal.intproxyhost",     "");
pref("aim.internal.intproxyport",     1080);
pref("aim.internal.intproxyuser",     "");
pref("aim.internal.intproxypassword", "");
pref("aim.internal.intproxyprotocol", 0);
pref("aim.internal.intisproxy",       false);
pref("aim.internal.intconnectiontype", 0);

/* session globals */
pref("aim.session.host.aim","login.oscar.aol.com");
pref("aim.session.port.aim", 5190);
pref("aim.session.proxyhost.aim",     "");
pref("aim.session.proxyport.aim",     1080);
pref("aim.session.proxyuser.aim",     "");
pref("aim.session.proxypassword.aim", "");
pref("aim.session.proxyprotocol.aim", 1);
pref("aim.session.isproxy.aim",       false);
/* 0 for just aim, 1 for just aol and 10 for both*/
pref("aim.session.connectiontype.aim", 0);


pref("aim.session.host.icq","login.icq.com");
pref("aim.session.port.icq", 5190);
pref("aim.session.proxyhost.icq",     "");
pref("aim.session.proxyport.icq",     1080);
pref("aim.session.proxyuser.icq",     "");
pref("aim.session.proxypassword.icq", "");
pref("aim.session.proxyprotocol.icq", 1);
pref("aim.session.isproxy.icq",       false);
pref("aim.session.connectiontype.icq", 2);

pref("aim.session.sn.aim", "Choose Screen Name");
pref("aim.session.sn.icq", "Choose Screen Name");
/* end new*/

/* aim button on personal toolbar glue */
pref("browser.toolbars.showbutton.AimPT", true);

/* pref to show/hide AIM and ICQ switcher */
pref("aim.session.hideconnection", false);

/* pref to show/hide new downstream registration wizard */
pref("aim.session.testingregistrationwizard", true);

pref("aim.session.listonly",       false);

/*autosignon to sns */
pref("aim.general.snsautosignon", false);

/* Buddy list view. 0 - ScreenName 1-Display NAme, 2 - Email Address */
pref("aim.session.buddyview", 0);

/* Support Mail-IM integration work based on a pref. If we decide later not to support this */
/* feature for Buffy, switch to false */

pref("aim.session.supportmailim", true);

/* Search directory for email address and display names - default is personal address book*/
pref("aim.session.searchDirectory", "moz-abmdbdirectory://abook.mab");

/* pref to enable preakness in Icq session */
pref("aim.session.icqpreakness", false);

==> netscape-7.2-i686-1.tgz: usr/lib/netscape/defaults/pref/aim.js <==
/* 0 is for BUCP(AIM), 1 is for TIH, 2 is for ICQ, 3 is for autosignon */
pref("aim.session.sessiontype", 0);

pref("aim.session.firsttry", false);
pref("aim.session.firsthost", "americaonline.aol.com");
pref("aim.session.firstport", 5200);

/* Set to ICQ to be default to ICQ */
pref("aim.session.userconnectionname", "AIM");

/* Proxy prefs for session */
pref("aim.proxy.use", false);
pref("aim.proxy.host", "");
pref("aim.proxy.port", 1080);
pref("aim.proxy.username", "");
pref("aim.proxy.password", "");
pref("aim.proxy.protocol", 1);
 

/* session pref defaults */
pref("aim.session.screenname","");
pref("aim.session.password","");
pref("aim.session.storepassword",false);
pref("aim.session.autologin",true);

/* last successfully signed on screenname of type */
pref("aim.session.latesticqscreenname","");
pref("aim.session.latestaimscreenname","");



/* gen global*/
pref("aim.session.firsttime",true);
pref("aim.session.appfirstlogin",true);
pref("aim.session.finishedwizard", false);

/* perSN*/
pref("aim.session.firstsignon",true);
pref("aim.session.autoreconnect", false);
pref("aim.session.reconnectdialog", false);
pref("aim.session.keepalive", false);



/* Mail integration per SN*/
pref("aim.mail.presence", true);
pref("aim.general.im.smilies", true);
pref("aim.general.im.enterCR", false);
pref("aim.general.im.tabKey", false);
pref("aim.general.im.timeStamp", false);

pref("aim.general.im.showtooltip", "false");
pref("aim.general.contactlist.displaymode", "false");
pref("aim.general.im.statusMode", "false");
pref("aim.general.contactlist.displaymode", "false");


/* no use, consider as gen global*/
pref("aim.im.flashonreceiveim", true);
pref("aim.im.showaccept",false);

/* gen global */
pref("aim.internal.buddy.MaxBuddies",100);


/* gen global */
pref("aim.buddy.TransitionTime",10);


pref("aim.buddy.SndPlaySignOn",true);
pref("aim.buddy.SndPlaySignOff",true);
pref("aim.buddy.SndPlaySignOn_ICQ",true);
/* XXXIMPL Put real sound path in here for the defaults */
pref("aim.buddy.SndSignOn","chrome://aim/skin/sounds/BuddySignon");
pref("aim.buddy.SndSignOn_ICQ","chrome://aim/skin/sounds/BuddySignon_ICQ");
/* XXXIMPL Put real sound path in here for the defaults */
pref("aim.buddy.SndSignOff","chrome://aim/skin/sounds/BuddySignoff");
pref("aim.buddy.SndBuddyOverride",false);
pref("aim.buddy.SndBuddyOverride_ICQ",false);
/* IM pref defaults */
pref("aim.im.playall", true);
pref("icq.im.playall", true);
pref("aim.buddy.SndPlayFirstIncoming",true);
pref("aim.buddy.SndPlayIncoming",true);
pref("aim.buddy.SndPlayOutgoing",true);
pref("aim.buddy.SndPlayFirstIncoming_ICQ",true);
pref("aim.buddy.SndPlayIncoming_ICQ",true);
pref("aim.buddy.SndPlayOutgoing_ICQ",true);
/* XXXIMPL Put real sound path in here for the defaults */
pref("aim.buddy.SndFirstIncoming","chrome://aim/skin/sounds/FirstIncomingIM");
pref("aim.buddy.SndIncoming","chrome://aim/skin/sounds/IncomingIM");
pref("aim.buddy.SndOutgoing","chrome://aim/skin/sounds/OutgoingIM");
pref("aim.buddy.SndFirstIncoming_ICQ","chrome://aim/skin/sounds/FirstIncoming_ICQ");
pref("aim.buddy.SndIncoming_ICQ","chrome://aim/skin/sounds/Incoming_ICQ");
pref("aim.buddy.SndOutgoing_ICQ","chrome://aim/skin/sounds/Outgoing_ICQ");




/* Privacy Pref Defaults */
/* no use, consider as gen global*/
pref("aim.privacy.view",3);
pref("aim.privacy.ChatBlockInvitations",false);
pref("aim.away.hidewindow", false);
pref("aim.away.idlereply", false);
pref("aim.away.disablereply", true);


/* perSN*/
pref("aim.privacy.knockknock",true);


/* perSN, (just for ICQ)*/
pref("aim.privacy.authorization",true);
pref("aim.privacy.onlinestatus",true);

/* perSN*/
pref("aim.away.autoreply", true);
pref("icq.away.autoreply", false);

/* no use, consider as gen global*/
pref("aim.throbber.url","chrome://aim-region/locale/region.properties");


/*AIM new added, perSN*/
pref("aim.general.today.aim", true);
pref("aim.general.today.icq", false);




/* Chat Pref Defaults pre SN, just AIM */
pref("aim.chat.SndPlayIncoming",true);
pref("aim.chat.SndPlayOutgoing",true);
/* IMPL Put real sound path in here for the defaults */
pref("aim.chat.SndIncoming","chrome://aim/skin/sounds/IncomingChat");
/* IMPL Put real sound path in here for the defaults */
pref("aim.chat.SndOutgoing","chrome://aim/skin/sounds/OutgoingChat");
pref("aim.chat.unavailable", false);
pref("aim.chat.FlashChatWin", true);
pref("aim.chat.AnnounceChatRoom", true);


/*Buddy Icons */
pref("aim.buddyicon.acceptfromBuddyList", true);
pref("aim.buddyicon.showknockknock", true);
pref("aim.buddyicon.neveraccept", false);

/*Buddy Icons */
pref("aim.buddyicon.displayBuddyIcons", 0); //0 - buddy list, 1 - never accept, 2 - never display BI.






/*new*/
/* per SN*/
pref("aim.session.connectionname", "AIM");

/* gen global*/


pref("aim.internal.extsessiontype",   0);
pref("aim.internal.extname",          "AIM");
pref("aim.internal.exthost",          "login.oscar.aol.com");
pref("aim.internal.extport",          5190);
pref("aim.internal.extproxyhost",     "");
pref("aim.internal.extproxyport",     1080);
pref("aim.internal.extproxyuser",     "");
pref("aim.internal.extproxypassword", "");
pref("aim.internal.extproxyprotocol", 0);
pref("aim.internal.extisproxy",       false);
pref("aim.internal.extconnectiontype", 0);


pref("aim.internal.intsessiontype",   0);
pref("aim.internal.intname",          "AIM");
pref("aim.internal.inthost",          "login.oscar.aol.com");
pref("aim.internal.intport",          5190);
pref("aim.internal.intproxyhost",     "");
pref("aim.internal.intproxyport",     1080);
pref("aim.internal.intproxyuser",     "");
pref("aim.internal.intproxypassword", "");
pref("aim.internal.intproxyprotocol", 0);
pref("aim.internal.intisproxy",       false);
pref("aim.internal.intconnectiontype", 0);

/* session globals */
pref("aim.session.host.aim","login.oscar.aol.com");
pref("aim.session.port.aim", 5190);
pref("aim.session.proxyhost.aim",     "");
pref("aim.session.proxyport.aim",     1080);
pref("aim.session.proxyuser.aim",     "");
pref("aim.session.proxypassword.aim", "");
pref("aim.session.proxyprotocol.aim", 1);
pref("aim.session.isproxy.aim",       false);
/* 0 for just aim, 1 for just aol and 10 for both*/
pref("aim.session.connectiontype.aim", 0);


pref("aim.session.host.icq","login.icq.com");
pref("aim.session.port.icq", 5190);
pref("aim.session.proxyhost.icq",     "");
pref("aim.session.proxyport.icq",     1080);
pref("aim.session.proxyuser.icq",     "");
pref("aim.session.proxypassword.icq", "");
pref("aim.session.proxyprotocol.icq", 1);
pref("aim.session.isproxy.icq",       false);
pref("aim.session.connectiontype.icq", 2);

pref("aim.session.sn.aim", "Choose Screen Name");
pref("aim.session.sn.icq", "Choose Screen Name");
/* end new*/

/* aim button on personal toolbar glue */
pref("browser.toolbars.showbutton.AimPT", false);

/* pref to show/hide AIM and ICQ switcher */
pref("aim.session.hideconnection", false);

/* pref to show/hide new downstream registration wizard */
pref("aim.session.testingregistrationwizard", true);

pref("aim.session.listonly",       false);

/*autosignon to sns */
pref("aim.general.snsautosignon", false);

/* Buddy list view. 0 - ScreenName 1-Display NAme, 2 - Email Address */
pref("aim.session.buddyview", 0);

/* Support Mail-IM integration work based on a pref. If we decide later not to support this */
/* feature for Buffy, switch to false */

pref("aim.session.supportmailim", true);

/* Search directory for email address and display names - default is personal address book*/
pref("aim.session.searchDirectory", "moz-abmdbdirectory://abook.mab");

/* pref to enable preakness in Icq session */
pref("aim.session.icqpreakness", false);
